@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 use utf8;
-use 5.10.0;
+use feature qw/state/;
 
 use Data::Dumper;
 use WebService::Slack::WebApi;
