@@ -5,6 +5,12 @@ use utf8;
 
 use parent 'WebService::Slack::WebApi::Base';
 
+use WebService::Slack::WebApi::Oauth::V2;
+
+use Class::Accessor::Lite::Lazy (
+    ro_lazy => [qw/ v2 /],
+);
+
 use WebService::Slack::WebApi::Generator (
     access => {
         client_id     => 'Str',
@@ -21,5 +27,9 @@ use WebService::Slack::WebApi::Generator (
     },
 );
 
+sub _build_v2 {
+    return WebService::Slack::WebApi::Oauth::V2->new(client => shift->client);
+}
+
 1;
 
